Autotest upstream merge.

Merged from d9d64b855363d214996b187380532d4cc9991d29 to
7bad38846fe9c74e42018131ce85aec2b5e6c7a9

BUG=none
TEST=emerge autotest, run bvt, smoke.

Change-Id: Ibe6462198e84e0d41fa160af086283cd712da4a6
Reviewed-on: http://gerrit.chromium.org/gerrit/7440
Tested-by: Dale Curtis <dalecurtis@chromium.org>
Reviewed-by: Dale Curtis <dalecurtis@chromium.org>
diff --git a/utils/run_pylint.py b/utils/run_pylint.py
index 3c3e225..515814a 100755
--- a/utils/run_pylint.py
+++ b/utils/run_pylint.py
@@ -53,15 +53,15 @@
 blacklist = ['/contrib/*', '/frontend/afe/management.py']
 
 # only show errors
 # there are two major sources of E1101/E1103 false positives:
 # * common_lib.enum.Enum objects
 # * DB model objects (scheduler models are the worst, but Django models also
 #   generate some errors)
 if pylint_version >= 0.21:
-    pylint_base_opts = ['--disable=W,R,C,E1101,E1103']
+    pylint_base_opts = ['--disable=W,R,C,E1101,E1103,E1120']
 else:
     pylint_base_opts = ['--disable-msg-cat=warning,refactor,convention',
-                        '--disable-msg=E1101,E1103']
+                        '--disable-msg=E1101,E1103,E1120']
 pylint_base_opts += ['--reports=no',
                      '--include-ids=y']
@@ -53,15 +53,15 @@
 
 # only show errors
-# there are two major sources of E1101/E1103 false positives:
+# there are three major sources of E1101/E1103/E1120 false positives:
 # * common_lib.enum.Enum objects
 # * DB model objects (scheduler models are the worst, but Django models also